@@ -486,6 +486,9 @@ function genericPrintNoParens(path, options, print) {
     case "ExportDefaultSpecifier":
         return path.call(print, "exported");
 
+    case "Import":
+        return fromString("import", options);
+
     case "ImportDeclaration":
         parts.push("import ");
 
@@ -568,9 +571,11 @@ function genericPrintNoParens(path, options, print) {
 
         if (n.argument) {
             var argLines = path.call(print, "argument");
-            if (argLines.length > 1 &&
-                namedTypes.JSXElement &&
-                namedTypes.JSXElement.check(n.argument)) {
+            if (argLines.startsWithComment() ||
+                (argLines.length > 1 &&
+                    namedTypes.JSXElement &&
+                    namedTypes.JSXElement.check(n.argument)
+                )) {
                 parts.push(
                     " (\n",
                     argLines.indent(options.tabWidth),
@@ -1078,6 +1083,9 @@ function genericPrintNoParens(path, options, print) {
     case "JSXSpreadAttribute":
         return concat(["{...", path.call(print, "argument"), "}"]);
 
+    case "JSXSpreadChild":
+        return concat(["{...", path.call(print, "expression"), "}"]);
+
     case "JSXExpressionContainer":
         return concat(["{", path.call(print, "expression"), "}"]);
 
@@ -1505,8 +1513,9 @@ function genericPrintNoParens(path, options, print) {
         return fromString(nodeStr(n.value, options), options);
 
     case "NumberLiteralTypeAnnotation":
+    case "NumericLiteralTypeAnnotation":
         assert.strictEqual(typeof n.value, "number");
-        return fromString("" + n.value, options);
+        return fromString(JSON.stringify(n.value), options);
 
     case "StringTypeAnnotation":
         return fromString("string", options);
